===
API
===

.. toctree::
    :maxdepth: 1

    verbs
    operators/index
    targets
    types
    aligned
    functions


.. currentmodule:: pydiverse.transform

Table
-----

.. autoclass:: Table

ColExpr
-------

.. autoclass:: ColExpr
   :members: dtype
   :exclude-members: __new__, __init__

Col
---

.. autoclass:: Col
   :no-index:
   :members: export
   :exclude-members: __new__, __init__
